<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>RemoveBlock</name>
    <message>
        <location filename="../RemoveBlockInit.js" line="+2"/>
        <source>&amp;Remove Block</source>
        <translation>&amp;Cancella blocco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delete selected block</source>
        <translation>Eliminare blocco selezionato</translation>
    </message>
</context>
</TS>
